## aiida-tbmodels

A plugin for [AiiDA](www.aiida.net) to run calculations with the [TBmodels](http://z2pack.ethz.ch/tbmodels) code.

Documentation: http://z2pack.ethz.ch/aiida-plugins/aiida-tbmodels
